"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const queryable_data_cube_1 = require("../../../common/models/data-cube/queryable-data-cube");
const sources_1 = require("../../../common/models/sources/sources");
const datacube_guard_1 = require("../datacube-guard/datacube-guard");
const request_errors_1 = require("../request-errors/request-errors");
async function parseDataCube(req, settings) {
    const dataCube = req.body.dataCube || req.body.dataCubeName || req.body.dataSource;
    if (typeof dataCube !== "string") {
        throw new request_errors_1.InvalidRequestError("must have a dataCube");
    }
    let sources;
    try {
        sources = await settings.getSources();
    }
    catch (e) {
        throw new request_errors_1.InvalidRequestError("Couldn't load settings");
    }
    const myDataCube = sources_1.getDataCube(sources, dataCube);
    if (!myDataCube) {
        throw new request_errors_1.InvalidRequestError("unknown data cube");
    }
    if (!queryable_data_cube_1.isQueryable(myDataCube)) {
        throw new request_errors_1.InvalidRequestError("un queryable data cube");
    }
    if (!(datacube_guard_1.checkAccess(myDataCube, req.headers))) {
        throw new request_errors_1.AccessDeniedError("access denied");
    }
    return myDataCube;
}
exports.parseDataCube = parseDataCube;
//# sourceMappingURL=parse-data-cube.js.map